class DepthwiseSeparableConv(Module):
  __parameters__ = []
  __buffers__ = []
  training : bool
  _is_full_backward_hook : Optional[bool]
  has_skip : bool
  has_pw_act : bool
  conv_dw : __torch__.torch.nn.modules.conv.___torch_mangle_0.Conv2d
  bn1 : __torch__.timm.layers.norm_act.BatchNormAct2d
  se : __torch__.timm.models._efficientnet_blocks.SqueezeExcite
  conv_pw : __torch__.torch.nn.modules.conv.___torch_mangle_3.Conv2d
  bn2 : __torch__.timm.layers.norm_act.___torch_mangle_4.BatchNormAct2d
  drop_path : __torch__.torch.nn.modules.linear.Identity
  def forward(self: __torch__.timm.models._efficientnet_blocks.DepthwiseSeparableConv,
    x: Tensor) -> Tensor:
    conv_dw = self.conv_dw
    x0 = (conv_dw).forward(x, )
    bn1 = self.bn1
    x1 = (bn1).forward(x0, )
    se = self.se
    x2 = (se).forward(x1, )
    conv_pw = self.conv_pw
    x3 = (conv_pw).forward(x2, )
    bn2 = self.bn2
    x4 = (bn2).forward(x3, )
    has_skip = self.has_skip
    if has_skip:
      drop_path = self.drop_path
      x6 = torch.add((drop_path).forward(x4, ), x)
      x5 = x6
    else:
      x5 = x4
    return x5
class SqueezeExcite(Module):
  __parameters__ = []
  __buffers__ = []
  training : bool
  _is_full_backward_hook : Optional[bool]
  conv_reduce : __torch__.torch.nn.modules.conv.___torch_mangle_1.Conv2d
  act1 : __torch__.torch.nn.modules.activation.SiLU
  conv_expand : __torch__.torch.nn.modules.conv.___torch_mangle_2.Conv2d
  gate : __torch__.torch.nn.modules.activation.Sigmoid
  def forward(self: __torch__.timm.models._efficientnet_blocks.SqueezeExcite,
    x: Tensor) -> Tensor:
    x_se = torch.mean(x, [2, 3], True)
    conv_reduce = self.conv_reduce
    x_se0 = (conv_reduce).forward(x_se, )
    act1 = self.act1
    x_se1 = (act1).forward(x_se0, )
    conv_expand = self.conv_expand
    x_se2 = (conv_expand).forward(x_se1, )
    gate = self.gate
    _0 = torch.mul(x, (gate).forward(x_se2, ))
    return _0
class InvertedResidual(Module):
  __parameters__ = []
  __buffers__ = []
  training : bool
  _is_full_backward_hook : Optional[bool]
  has_skip : bool
  conv_pw : __torch__.torch.nn.modules.conv.___torch_mangle_5.Conv2d
  bn1 : __torch__.timm.layers.norm_act.___torch_mangle_6.BatchNormAct2d
  conv_dw : __torch__.torch.nn.modules.conv.___torch_mangle_7.Conv2d
  bn2 : __torch__.timm.layers.norm_act.___torch_mangle_6.BatchNormAct2d
  se : __torch__.timm.models._efficientnet_blocks.___torch_mangle_10.SqueezeExcite
  conv_pwl : __torch__.torch.nn.modules.conv.___torch_mangle_11.Conv2d
  bn3 : __torch__.timm.layers.norm_act.___torch_mangle_12.BatchNormAct2d
  drop_path : __torch__.torch.nn.modules.linear.Identity
  def forward(self: __torch__.timm.models._efficientnet_blocks.InvertedResidual,
    x: Tensor) -> Tensor:
    conv_pw = self.conv_pw
    x7 = (conv_pw).forward(x, )
    bn1 = self.bn1
    x8 = (bn1).forward(x7, )
    conv_dw = self.conv_dw
    x9 = (conv_dw).forward(x8, )
    bn2 = self.bn2
    x10 = (bn2).forward(x9, )
    se = self.se
    x11 = (se).forward(x10, )
    conv_pwl = self.conv_pwl
    x12 = (conv_pwl).forward(x11, )
    bn3 = self.bn3
    x13 = (bn3).forward(x12, )
    has_skip = self.has_skip
    if has_skip:
      drop_path = self.drop_path
      x15 = torch.add((drop_path).forward(x13, ), x)
      x14 = x15
    else:
      x14 = x13
    return x14
